@@ -1,13 +1,13 @@
-/* 
+/*
  *  IMS Open Corpus Workbench (CWB)
  *  Copyright (C) 1993-2006 by IMS, University of Stuttgart
  *  Copyright (C) 2007-     by the respective contributers (see file AUTHORS)
- * 
+ *
  *  This program is free software; you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by the
  *  Free Software Foundation; either version 2, or (at your option) any later
  *  version.
- * 
+ *
  *  This program is distributed in the hope that it will be useful, but
  *  WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
@@ -15,15 +15,12 @@
  *  WWW at http://www.gnu.org/copyleft/gpl.html).
  */
 
-#ifndef _VARIABLES_H_
-#define _VARIABLES_H_
+#ifndef _cqp_variables_h_
+#define _cqp_variables_h_
 
-/* ---------------------------------------------------------------------- */
 
-#include "../cl/corpus.h"
-#include "../cl/attributes.h"
+#include "../cl/cl.h"
 
-/* ---------------------------------------------------------------------- */
 
 /** VariableItem object: an item within a variable */
 typedef struct _variable_item {
@@ -36,9 +33,8 @@ typedef struct _variable_item {
 } VariableItem;
 
 /**
- * The Variable object: a list of strings that can be used as a variable within
- * a query (to match all tokens whose type is identical to one of the strings
- * on the list).
+ * The Variable object: a list of strings that can be used as a variable within a query
+ * (to match all tokens whose type is identical to one of the strings on the list).
  *
  * (Plus also VariableBuffer: the former is a pointer to the latter.)
  */
@@ -53,10 +49,10 @@ typedef struct _variable_buf {
 
   int nr_valid_items;     /**< only valid after validation */
   int nr_invalid_items;
-  
+
   int nr_items;           /**< number of items (size of the "items" array) */
   VariableItem *items;    /**< array of items - the set of strings within the variable. */
-  
+
 } VariableBuffer, *Variable;
 
 extern int nr_variables;
@@ -66,40 +62,22 @@ extern Variable *VariableSpace;
 
 /* Variable methods */
 
-Variable FindVariable(char *varname);
-
-int VariableItemMember(Variable v, char *item);
-
-int VariableAddItem(Variable v, char *item);
+Variable FindVariable(const char *varname);
 
+int VariableItemMember(Variable v, const char *item);
+int VariableAddItem(Variable v, const char *item);
 int VariableSubtractItem(Variable v, const char *item);
-
 int VariableDeleteItems(Variable v);
 
-int DropVariable(Variable *vp);
-
-Variable NewVariable(char *varname);
-
-int
-SetVariableValue(char *varName, 
-                 char operator,
-                 char *varValues);
+Variable NewVariable(const char *varname);
+int SetVariableValue(const char *varname, char operator, char *values);
 
 /* variable iterator functions */
 void variables_iterator_new(void);
 Variable variables_iterator_next(void);
 
-
-int
-VerifyVariable(Variable v, Corpus *corpus, Attribute *attribute);
-
-int *
-GetVariableItems(Variable v, 
-                 Corpus *corpus,
-                 Attribute *attribute,
-                 /* returned: */
-                 int *nr_items);
-
+int VerifyVariable(Variable v, Corpus *corpus, Attribute *attribute);
+int *GetVariableItems(Variable v, Corpus *corpus, Attribute *attribute, int *nr_items);
 char **GetVariableStrings(Variable v, int *nr_items);
 
 #endif
