@@ -1,13 +1,13 @@
-/* 
+/*
  *  IMS Open Corpus Workbench (CWB)
  *  Copyright (C) 1993-2006 by IMS, University of Stuttgart
  *  Copyright (C) 2007-     by the respective contributers (see file AUTHORS)
- * 
+ *
  *  This program is free software; you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by the
  *  Free Software Foundation; either version 2, or (at your option) any later
  *  version.
- * 
+ *
  *  This program is distributed in the hope that it will be useful, but
  *  WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
@@ -15,7 +15,8 @@
  *  WWW at http://www.gnu.org/copyleft/gpl.html).
  */
 
-
+#ifndef _utils_barlib_h_
+#define _utils_barlib_h_
 
 /**
  * The BARdesc object: a BAR (Beamed Array) descriptor.
@@ -58,3 +59,5 @@ void BAR_write(BARdesc BAR, int x, int y, int i);
 
 int BAR_read(BARdesc BAR, int x, int y);
 
+
+#endif
